#include <inttypes.h>
#include <utility>
#include <stdio.h>

#include <AP_HAL/AP_HAL.h>
#include <AP_HAL/I2CDevice.h>
#include <AP_Math/AP_Math.h>
#include "Dads.h"

extern const AP_HAL::HAL& hal;
static const uint8_t DADS_CMD   = 0x00;

#define Arduino_ADDR 2 //direccion del semaforo de I2C

Dads::Dads():
	_dev(nullptr),
	_results(0),
	_healthy(false)

{
	memset(&_k, 0, sizeof(_k));
}

bool Dads::init()
{
	uint8_t buff; 

    	// take a pointer to the i2c bus semaphore
	_dev = std::move(hal.i2c_mgr->get_device(0, DADS_ADDR));
    	if(!_dev){
		_dev = std::move(hal.i2c_mgr->get_device(1, DADS_ADDR));
	}
    
    	if (!_dev) {
        	return false;
    	}

    	// take the semaphore
    	if (!_dev->get_semaphore()->take(HAL_SEMAPHORE_BLOCK_FOREVER)) {
		return false;
    	}
    
    	// read initial sensors

    	if(!_dev->read((uint8_t *) &buff, sizeof(buff))){
		_dev->get_semaphore()->give(); //if it fail, release the semaphore
		return false;
    	}

    	_dev->get_semaphore()->give(); //give the semaphore
    	return true;
}

bool Dads::read()
{
	uint8_t buff=0;

	// get the i2c bus, semaphore
	if (!_dev->get_semaphore()->take(HAL_SEMAPHORE_BLOCK_FOREVER)) {
		return false;
	}

	// read data from sensor
	if (!_dev->read((uint8_t *) &buff, sizeof(buff))) {
		_dev->get_semaphore()->give();//if it fail, release the semaphore
        	return false;
	}

	_results=buff;//store the value on _result
	_dev->get_semaphore()->give();//give the semaphore
	return true;
}







